@@ -1,5 +1,6 @@
 from tqdm import *
 from time import sleep
+import time
 from random import randint,choice
 from os import system,urandom
 from termcolor import colored
@@ -14,14 +15,14 @@ print(colored("Welcome to F61D. Use Help() for help.",'green'))
 help_cont = {}
 help_cont[0] = 'Help     : See this help page'
 help_cont[1] = 'fuckStar : One Button to fuck Satellite'
-help_cont[2] = 'lifeGame : Play the Life Game'
+help_cont[9] = 'lifeGame : Play the Life Game'
 help_cont[3] = 'paint    : Draw a Bing Dwen Dwen'
 help_cont[4] = 'b64tofile: Decode base64 to a file'
 help_cont[5] = 'prove    : Prove your self. Only support:\n                  sha256(XXXX + abcdef) = aaabbb...'
 help_cont[6] = 'Nim      : An interesting turtle game.'
 help_cont[7] = 'getLogo  : Print the "F61D" LOGO.'
 help_cont[8] = 'yinyang  : Draw the TaiJi.'
-
+help_cont[2] = 'timeit   : Take a time for your function.\n\t\t  Just add a '+colored('@timeit','cyan')+colored(' before you define the function','green')
 
 def Help(page=1,lines = 5):
     maxPage = int((0.5+len(help_cont))/lines)+1
@@ -103,6 +104,19 @@ def Nim():
     game()
 
 
+def timeit(fun):
+    
+    def wrapper(*args,**kwargs):
+        
+        t1 = time.time()
+        ret = fun(*args,**kwargs)
+        print(f'Function takes {time.time() - t1}s')
+
+        return ret
+    
+    return wrapper
+
+
 def prove(cont):
     '''
     Only the format is supported
